import { createNativeStackNavigator } from "@react-navigation/native-stack"
import { NavigationContainer } from "@react-navigation/native"
import { IconButton } from "native-base"
import { AntDesign } from "@expo/vector-icons"
import { createDrawerNavigator } from "@react-navigation/drawer"
import { useSelector } from "react-redux"
import { RootState } from "../stores/store"
import { nativeBaseTheme } from "../theme/nativeBaseTheme"
import HomePage from "./HomePage"
import LoginPage from "./LoginPage"
import SearchPage from "./SearchPage"
import Logout from "./Logout"
import ItemViewPage from "./ItemViewPage"
import NotesViewPage from "./NotesViewPage"

export type RootDrawerParamList = {
    Home: undefined,
    Search: { inventoryId: string | null },
    Logout: undefined,
    Item: { itemId: string },
    Login: undefined,
    Notes: undefined,
}

const Navigation = () => {
    const Drawer = createDrawerNavigator<RootDrawerParamList>()
    const loggedIn = useSelector((state: RootState) => state.user.loggedIn)

    return (
        <NavigationContainer>
            <Drawer.Navigator useLegacyImplementation
                screenOptions={({ navigation }) => ({
                    headerStyle: {
                        backgroundColor: nativeBaseTheme.colors.primary[800],
                    },
                    headerTintColor: '#fff',
                    headerTitleStyle: {
                        fontWeight: 'bold',
                    },
                    headerRight: () => (
                        <IconButton
                            onPress={() => navigation.navigate("Search", {inventoryId: null})}
                            title="Info"
                            color="#fff"
                            _icon={{
                                as: AntDesign,
                                name: "search1",
                                color: "white"
                            }}
                        />
                    ),
                })}
            >
                {loggedIn ? (
                    <>
                        <Drawer.Screen
                            name="Home"
                            component={HomePage}
                            options={{
                                title: 'My home'
                            }}
                        />
                        <Drawer.Screen
                            name="Search"
                            component={SearchPage}
                            initialParams={{inventoryId: null}}
                        />
                        <Drawer.Screen
                            name={"Notes"}
                            component={NotesViewPage}
                        />
                        <Drawer.Screen
                            name="Logout"
                            component={Logout}
                        />
                        <Drawer.Screen
                            name={"Item"}
                            component={ItemViewPage}
                            options={{ drawerItemStyle: { display: "none" } }}
                        />
                    </>
                ) : (
                    <Drawer.Screen
                        name="Login"
                        component={LoginPage}
                        options={({ navigation }) => ({
                            headerRight: () => (
                                <></>
                            )
                        })}
                    />
                )}
            </Drawer.Navigator>
        </NavigationContainer>
    )

}

export default Navigation